@@ -4,7 +4,7 @@ package OpenSky::API;
 
 # ABSTRACT: Perl interface to the OpenSky Network API
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 use Moose;
 use OpenSky::API::Types qw(
   ArrayRef
@@ -318,7 +318,7 @@ OpenSky::API - Perl interface to the OpenSky Network API
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -359,7 +359,10 @@ If you want to use the other methods, you will need to provide a username and pa
         password => 'password',
     );
 
-Alterantively, you can set the C<OPENSKY_USERNAME> and C<OPENSKY_PASSWORD>
+You can get a username and password by registering for a free account on
+L<OpenSky Network|https://opensky-network.org>.
+
+Alternatively, you can set the C<OPENSKY_USERNAME> and C<OPENSKY_PASSWORD>
 environment variables, or create a C<.openskyrc> file in your home directory
 with the following contents:
 
@@ -367,6 +370,12 @@ with the following contents:
     username = myusername
     password = s3cr3t
 
+If you'd like that file in another directory, just pass the C<config> argument:
+
+    my $open_sky = OpenSky::API->new(
+        config => '/path/to/config',
+    );
+
 By default, all methods return objects. If you want to get the raw results, you can set the C<raw>
 attribute in the constructor:
 
@@ -374,7 +383,8 @@ attribute in the constructor:
         raw => 1,
     );
 
-If you are debugging why something failed, pass the C<debug> attribute:
+If you are debugging why something failed, pass the C<debug> attribute to see
+a C<STDERR> trace of the requests and responses:
 
     my $open_sky = OpenSky::API->new(
         debug => 1,
@@ -385,6 +395,12 @@ If you are debugging why something failed, pass the C<debug> attribute:
 For more insight to all methods, see L<the OpenSky API
 documentation|https://openskynetwork.github.io/opensky-api/>.
 
+Note a key difference between the Python implementation and this one: the
+Python implementation returns <None> if results are not found. For this
+module, you will still receive the iterator, but it won't have any results.
+This allows you to keep a consistent interface without having to check for
+C<undef> everywhere.
+
 =head2 get_states
 
     my $states = $api->get_states;
@@ -540,6 +556,15 @@ The first argument is the ICAO24 transponder address of the aircraft you want.
 Returns an instance of L<OpenSky::API::Flights>. if C<< raw => 1 >> was passed
 to the constructor, you will get the raw data structure instead.
 
+=head2 C<limit_remaining>
+
+    my $limit = $api->limit_remaining;
+
+The methods to retrieve state vectors of sensors other than your own are rate
+limited. As of this writing, this is only C<get_states>. See
+L<limitations|https://openskynetwork.github.io/opensky-api/rest.html#limitations>
+for more details.
+
 =head1 EXAMPLES
 
 Perl Wikipedia, L<OpenSky Network|https://en.wikipedia.org/wiki/OpenSky_Network> is ...
