@@ -2,10 +2,9 @@
 
 package OpenSky::API::Core::StateVector;
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 use Moose;
 use experimental qw(signatures);
-extends 'OpenSky::API::Core';
 
 my @PARAMS = qw(
   icao24
@@ -28,6 +27,12 @@ my @PARAMS = qw(
   category
 );
 
+around 'BUILDARGS' => sub ( $orig, $class, $state ) {
+    my %value_for;
+    @value_for{ $class->_get_params } = @$state;
+    return $class->$orig(%value_for);
+};
+
 has [@PARAMS] => ( is => 'ro', required => 1 );
 
 sub _get_params ($class) {
@@ -89,7 +94,7 @@ OpenSky::API::Core::StateVector - A class representing a state from the OpenSky
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
